/****************************************************************************/
/*  Test DMX512 + MOD-24LR / nrf24L01                                       */
/****************************************************************************/
/*  LEnsE / Julien VILLEMEJANE       /   Institut d'Optique Graduate School */
/*  Barthélémy DEMEER  Solène LESINQ  Lou PORTELLI  Isidor TOUKAM           */
/****************************************************************************/
/****************************************************************************/
/*  Test réalisé sur Nucléo-L476RG                                          */
/****************************************************************************/


#include    "mbed.h"
#include    "DMX_MIDI.h"
#include    "projecteurs.h"
#include    "controleurs.h"



Serial          debug_pc(USBTX, USBRX);
InterruptIn     bp_int(USER_BUTTON);
DigitalOut      debug_out(D13);     // Déclaration de la sortie digitale de la carte Nucléo

/*                ***  DECLARATION DES LAMPES  ***              */

// On prête attention aux adresses des lampes LED, pour qu'elles correspondent à ces listes

int lampe1[]={0,1,2,3,4,5,6};
int lampe2[]={8,9,10,11,12,13,14};
int lampe3[]={16,17,18,19,20,21,22}; 
int lampe4[]={24,25,26,27,28,29,30};

/*                ***  DECLARATION DES PADS  ***              */

// Valeurs des pads donnés grâce au logiciel MIDI Monitor

int pad1=0x24;
int pad2=0x25;
int pad3=0x26;
int pad4=0x27;
int pad5=0x28;
int pad6=0x29;
int pad7=0x2A;
int pad8=0x2B;
int pad9=0x2C;
int pad10=0x2D;
int pad11=0x2E;
int pad12=0x2F;
int pad13=0x30;
int pad14=0x31;
int pad15=0x32;
int pad16=0x33;

/*                   ***   SETS DE COULEURS  ***                  */

// set_lumière[]= {valeur_luminosité, valeur_rouge, valeur_vert, valeur_bleu, valeur_blanc, valeur_stob, valeur_stob}

// Les valeurs vont de 0 à 255, de 0% à 100%

int blackout[]={0,0,0,0,0,0,0};
int blanc[]={255,200,250,120,255,0,0};
int rouge[]={255,255,0,0,0,0,0};
int bleu[]={255,0,0,255,0,0,0};
int vert[]={255,0,255,0,0,0,0};
int violet[]={255,138,43,226,0,0,0};
int orange[]={255,255,165,0,0,0,0};
int jaune[]={255,255,200,0,255,0,0};
int rose[]={255,255,20,147,0,0,0};
int rose_chaud[]={255,255,100,75,0,0,0};
int bleuclair[]={255,0,191,255,0,0,0};
int vertlime[]={255,50,205,50,0,0,0};
int marron[]={255,139,69,19,0,0,0};

// Couleurs confectionnées par les membres du projet

int barth[]={255,100,149,238,255,0,0};
int lou[]={255,50,205,50,0,0,0};
int solene[]={255,255,69,0,0,0,0};


// Fonction utilisée pour allumer les LEDs, voir fin du main

void allumer(int lampe[], int couleur[]);

// Utilisation du module Ticker pour l'alternance des sets de lumière automatique 

Ticker tik;
void int_tik();     // Voir fonction à la fin du main
int seq1;
int cpt;





/*              *** FONCTION MAIN ***               */

int main() {
    debug_pc.baud(115200);
    
    
    // Initialisation périphériques
    initDMX();
    initMIDI();
    //printf("Test\r\n");     Test affiché à la console pour s'assurer que l'initialisation s'effectue

    // A l'entrée du main, la LED 1 affiche une couleur bleue. Les autres sont éteintes

        dmx_data[0] = 255;  
        dmx_data[1] = 0;
        dmx_data[2] = 0;  
        dmx_data[3] = 255;   
        dmx_data[4] = 0;
        dmx_data[5] = 0;
        dmx_data[6] = 0;
     

      

      tik.attach(&int_tik,1);       //Initialisation du Ticker
      seq1=0;
      cpt=0;

    while(1) { 
        /* MIDI */
        
        if(isNoteMIDIdetected()){
            updateProjFromMidi(note_data);
            playNoteMIDI2(note_data, velocity_data);


            if(note_data == pad9){          /*Bliss*/
                printf("ok");

                allumer(lampe1, rouge); //Isidor
                allumer(lampe2, barth); 
                allumer(lampe3, lou);  
                allumer(lampe4, solene);  
            }
            if(note_data == pad15){         /*Vert*/
                allumer(lampe1, vert);
                allumer(lampe2, vert);
                allumer(lampe3, vert);
                allumer(lampe4, vert);
            }                
        
         if(note_data == pad13){            /*Blackout*/
                seq1=0;     // Permet d'interrompre la séquence Ticker
                cpt=0;
                allumer(lampe1, blackout);
                allumer(lampe2, blackout);
                allumer(lampe3, blackout);
                allumer(lampe4, blackout);
            }

        if(note_data == pad14){             /*Rouge*/
                allumer(lampe1, rouge);
                allumer(lampe2, rouge);
                allumer(lampe3, rouge);
                allumer(lampe4, rouge);
            }

        if(note_data == pad16){             /*Bleu*/
                allumer(lampe1, bleu);
                allumer(lampe2, bleu);
				allumer(lampe3, bleu);
                allumer(lampe4, bleu);
            }
            
        if(note_data == pad11){             /*Violet*/
                allumer(lampe1, marron);
                allumer(lampe2, rose);
                allumer(lampe3, bleuclair);
                allumer(lampe4, violet);
            }
            
        if(note_data == pad10){             /* Ambiance multicolorée*/
                // Exemple du codage avant la fonction "allumer". Codage plus lourd et très répétitif

                dmx_data[0] = 255;  
                dmx_data[1] = 200;
                dmx_data[2] = 0;  
                dmx_data[3] = 200;   
                dmx_data[5] = 0;
                dmx_data[6] = 0;
                dmx_data[8] = 255;  
                dmx_data[9] = 0;
                dmx_data[10] = 0;  
                dmx_data[11] = 54;   
                dmx_data[12] = 12;
                dmx_data[13] = 0; 
                dmx_data[14] = 0;
                dmx_data[16] = 255;  
                dmx_data[17] = 255;
                dmx_data[18] = 0;  
                dmx_data[19] = 0;   
                dmx_data[20] = 0;
                dmx_data[21] = 0; 
                dmx_data[22] = 0;
                dmx_data[24] = 255;
                dmx_data[25] = 0;
                dmx_data[26] = 255;
                dmx_data[27] = 90;
                dmx_data[28] = 0;
                dmx_data[29] = 0;
                dmx_data[30] = 0;
            }
        if(note_data == pad12){                 /* Ambiance Bleue*/
                // Même exemple

                dmx_data[0] = 255;  
                dmx_data[1] = 60;
                dmx_data[2] = 70;  
                dmx_data[3] = 200;   
                dmx_data[5] = 0;
                dmx_data[6] = 0;
                dmx_data[8] = 255;  
                dmx_data[9] = 0;
                dmx_data[10] = 140;  
                dmx_data[11] = 0;   
                dmx_data[12] = 70;
                dmx_data[13] = 0; 
                dmx_data[14] = 0;
                dmx_data[16] = 255;  
                dmx_data[17] = 25;
                dmx_data[18] = 120;  
                dmx_data[19] = 120;   
                dmx_data[20] = 0;
                dmx_data[21] = 0; 
                dmx_data[22] = 0;
                dmx_data[24] = 255;
                dmx_data[25] = 0;
                dmx_data[26] = 55;
                dmx_data[27] = 90;
                dmx_data[28] = 255;
                dmx_data[29] = 0;
                dmx_data[30] = 0;
            }
            
        if (note_data == pad5){ /* Première tentative d'alternance des sets - UTILISATION DU wait_us*/
                
                allumer(lampe1, violet);
                allumer(lampe2, jaune);
                allumer(lampe3, jaune);
                allumer(lampe4, violet);
                wait(0.5);
                updateDMX();
                allumer(lampe1, bleuclair);
                allumer(lampe2, bleuclair);
                allumer(lampe3, orange);
                allumer(lampe4, orange);
                wait(0.5);
                updateDMX();
                allumer(lampe1, rose);
                allumer(lampe2, blanc);
                allumer(lampe3, blanc);
                allumer(lampe4, rouge);
                wait(0.500);
                updateDMX();
                allumer(lampe1, bleu);
                allumer(lampe2, bleu);
                allumer(lampe3, marron);
                allumer(lampe4, marron);
                wait(0.500);
                updateDMX();
                }

        if(note_data == pad6){          /* Set à la demande de Mélissa TECHER */
                allumer(lampe1, orange);
                allumer(lampe2, vert);
                allumer(lampe3, jaune);
                allumer(lampe4, bleu); 
            }

        if(note_data == pad1){              /* Set HIVER */
                allumer(lampe1, bleuclair);
                allumer(lampe2, blanc);
                allumer(lampe3, bleuclair);
                allumer(lampe4, blanc);
            }
        
        if(note_data == pad2){              /* Set PRINTEMPS */
                allumer(lampe1, rose_chaud);
                allumer(lampe2, vert);
                allumer(lampe3, vertlime);
                allumer(lampe4, jaune);
            }        

        if(note_data == pad3){              /* Set ÉTÉ */
                allumer(lampe1, orange);
                allumer(lampe2, vertlime);
                allumer(lampe3, orange);
                allumer(lampe4, bleuclair);
            }        

        if(note_data == pad4){              /* Set AUTOMNE */
                allumer(lampe1, orange);
                allumer(lampe2, solene);
                allumer(lampe3, jaune);
                allumer(lampe4, solene);
            }        

        if(note_data == pad7){              /* Blanc */
                allumer(lampe1, blanc);
                allumer(lampe2, blanc);
                allumer(lampe3, blanc);
                allumer(lampe4, blanc);
            }        
        if(note_data == pad8){ /* Seconde tentative d'alternance des sets - UTILISATION DU Ticker */
    
                seq1=1;     // Initialisation de la séquence pour rentrer dans le Ticker
            }        

        }
        updateDMX();
        wait_us(10000);
        
    }

}

void allumer(int lampe[], int couleur[]){ //Assigne à l'adresse d'une LED la valeur de couleur du set
    dmx_data[lampe[0]]=couleur[0];
    dmx_data[lampe[1]]=couleur[1];
    dmx_data[lampe[2]]=couleur[2];
    dmx_data[lampe[3]]=couleur[3];
    dmx_data[lampe[4]]=couleur[4];
    dmx_data[lampe[5]]=couleur[5];
    dmx_data[lampe[6]]=couleur[6];
    }

void int_tik(){     // Utilisation du Ticker pour l'alternance des sets
    if(seq1==1){
        if(cpt==0){ // La séquence comprend 4 sets qui se répète jusqu'à ce que l'utilisateur revienne au Blackout
            
                allumer(lampe1,bleu);
                allumer(lampe2,bleu);
                allumer(lampe3,rouge);
                allumer(lampe4,bleu);
                }
        if(cpt==1) {       
        
                allumer(lampe1,blanc);
                allumer(lampe2,blanc);
                allumer(lampe3,blanc);
                allumer(lampe4,blanc); 
                }
                
        if(cpt==2){
                allumer(lampe1,rouge);
                allumer(lampe2,rouge);
                allumer(lampe3,rouge);
                allumer(lampe4,rouge);
                 }
                
        if(cpt==3){
                allumer(lampe1,bleu);
                allumer(lampe2,blanc);
                allumer(lampe3,blanc);
                allumer(lampe4,rouge);
                }
                
           
            
        if(seq1==1){
            cpt=cpt+1;
            if(cpt==4){
                cpt=0;
            }
        }
        
        
        

        
    }
}